==> ns-sso-client-2.0.0-20250929.025343-43-sources.jar: com/geoway/sso/client/util/HttpUtils.java <==
package com.geoway.sso.client.util;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.alibaba.fastjson2.util.ParameterizedTypeImpl;
import com.geoway.sso.client.rpc.Result;
import com.geoway.sso.client.rpc.RpcPage;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import java.io.IOException;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author ALMJ
 * @desc Http请求
 */
public class HttpUtils {
    private static final Logger logger = LoggerFactory.getLogger(HttpUtils.class);

    public static <T> Result<T> getHttp(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        return JSONObject.parseObject(jsonStr, new TypeReference<Result<T>>(clazz) {
        });
    }


    public static <T> Result<List<T>> getHttpList(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, List.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public static <T> Result<RpcPage<T>> getHttpPage(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, RpcPage.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public  static <T> Result<T> postHttp(String url, Map<String, String> paramMap,Map<String, String> headerMap, Object jsonObject,Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        return JSONObject.parseObject(jsonStr, new TypeReference<Result<T>>(clazz) {
        });
    }



    public  static <T> Result<List<T>> postHttpList(String url, Map<String, String> paramMap,Map<String, String> headerMap, Object jsonObject,Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, List.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public  static <T> Result<RpcPage<T>> postHttpPage(String url, Map<String, String> paramMap, Map<String, String> headerMap, Object jsonObject, Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, RpcPage.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }

    public static String get(String url, Map<String, String> paramMap,Map<String, String> headerMap) {
        String result = null;
        CloseableHttpResponse response = null;
        String realUrl = url;
        CloseableHttpClient httpClient = HttpClients.createDefault();
        try {
            if (paramMap != null && !paramMap.isEmpty()) {
                List<NameValuePair> params = new ArrayList<>();
                for (Map.Entry<String, String> entry : paramMap.entrySet()) {
                    params.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
                }
                String paramStr = EntityUtils.toString(new UrlEncodedFormEntity(params, "UTF-8"));
                realUrl += "?" + paramStr;
            }
            HttpGet httpGet = new HttpGet(realUrl);
            if (headerMap != null && !headerMap.isEmpty()) {
                for (Map.Entry<String, String> headerItem : headerMap.entrySet()) {
                    httpGet.setHeader(headerItem.getKey(), headerItem.getValue());
                }
            }
            response = httpClient.execute(httpGet);
            if (response != null && response.getStatusLine().getStatusCode() == 200) {
                HttpEntity entity = response.getEntity();
                if (entity != null) {
                    result = EntityUtils.toString(entity);
                }
                logger.info("url: {}, result: {}", url, result);
            }
            return result;
        } catch (Exception e) {
            logger.error("url: {}, result: {}", url, result, e);
            throw new RuntimeException(e);
        } finally {
            try {
                httpClient.close();
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                logger.error("", e);
                throw new RuntimeException(e);
            }
        }
    }

    public static String get(String url, Map<String, String> paramMap) {
      return get(url,paramMap,null);
    }

    public static String get(String url) {
        return get(url, null);
    }

    public static String post(String url, Map<String, String> paramMap, Map<String, String> headerMap) {
       return post(url,paramMap,headerMap,null);
    }

    public static String post(String url, Map<String, String> paramMap, Map<String, String> headerMap,String jsonStr) {
        HttpPost httpPost = null;
        CloseableHttpClient httpClient = null;
        try {
            httpPost = new HttpPost(url);
            if (paramMap != null && !paramMap.isEmpty()) {
                List<NameValuePair> formParams = new ArrayList<>();
                for (Map.Entry<String, String> entry : paramMap.entrySet()) {
                    formParams.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
                }
                httpPost.setEntity(new UrlEncodedFormEntity(formParams, "UTF-8"));
            }
            RequestConfig requestConfig = RequestConfig.custom().setSocketTimeout(50000).setConnectTimeout(50000).build();
            httpPost.setConfig(requestConfig);

            if (headerMap != null && !headerMap.isEmpty()) {
                for (Map.Entry<String, String> headerItem : headerMap.entrySet()) {
                    httpPost.setHeader(headerItem.getKey(), headerItem.getValue());
                }
            }
             if(StringUtils.isNotEmpty(jsonStr)){
                 StringEntity stringEntity=new StringEntity(jsonStr);
                 stringEntity.setContentType("application/json");
                 stringEntity.setContentEncoding("UTF-8");
             }
            httpClient = HttpClients.custom().disableAutomaticRetries().build();

            HttpResponse response = httpClient.execute(httpPost);
            HttpEntity entity = response.getEntity();
            if (entity != null && response.getStatusLine().getStatusCode() == 200) {
                String result = EntityUtils.toString(entity, "UTF-8");
                EntityUtils.consume(entity);
                logger.info("url: {}, result: {}", url, result);
                return result;
            }
            return null;
        } catch (Exception e) {
            logger.error("url: {}, paramMap: {}", url, paramMap, e);
            throw new RuntimeException(e);
        } finally {
            if (httpPost != null) {
                httpPost.releaseConnection();
            }
            if (httpClient != null) {
                try {
                    httpClient.close();
                } catch (IOException e) {
                    logger.error("", e);
                }
            }
        }
    }

    public static String post(String url, Map<String, String> paramMap) {
        return post(url, paramMap, null);
    }

    public static String postHeader(String url, Map<String, String> headerMap) {
        return post(url, null, headerMap);
    }
}

==> ns-sso-client-2.0.0-20251119.012106-64-sources.jar: com/geoway/sso/client/util/HttpUtils.java <==
package com.geoway.sso.client.util;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.alibaba.fastjson2.util.ParameterizedTypeImpl;
import com.geoway.sso.client.rpc.Result;
import com.geoway.sso.client.rpc.RpcPage;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


import java.io.IOException;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author ALMJ
 * @desc Http请求
 */
public class HttpUtils {
    private static final Logger logger = LoggerFactory.getLogger(HttpUtils.class);

    public static <T> Result<T> getHttp(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        return JSONObject.parseObject(jsonStr, new TypeReference<Result<T>>(clazz) {
        });
    }


    public static <T> Result<List<T>> getHttpList(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, List.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public static <T> Result<RpcPage<T>> getHttpPage(String url, Map<String, String> paramMap,Map<String, String> headerMap,Class<T> clazz) {
        String jsonStr = HttpUtils.get(url, paramMap,headerMap);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, RpcPage.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public  static <T> Result<T> postHttp(String url, Map<String, String> paramMap,Map<String, String> headerMap, Object jsonObject,Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        return JSONObject.parseObject(jsonStr, new TypeReference<Result<T>>(clazz) {
        });
    }



    public  static <T> Result<List<T>> postHttpList(String url, Map<String, String> paramMap,Map<String, String> headerMap, Object jsonObject,Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, List.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }
    public  static <T> Result<RpcPage<T>> postHttpPage(String url, Map<String, String> paramMap, Map<String, String> headerMap, Object jsonObject, Class<T> clazz) {
        String jsonObjectStr="";
        if(jsonObject!=null){
            jsonObjectStr=JSONObject.toJSONString(jsonObject);
        }

        String jsonStr = HttpUtils.post(url, paramMap,headerMap,jsonObjectStr);
        if (jsonStr == null || jsonStr.isEmpty()) {
            logger.error("url:{} 异常, return null.", url);
            return null;
        }
        ParameterizedTypeImpl inner = new ParameterizedTypeImpl(new Type[]{clazz}, null, RpcPage.class);
        ParameterizedTypeImpl outer = new ParameterizedTypeImpl(new Type[]{inner}, null, Result.class);
        return JSONObject.parseObject(jsonStr, outer);
    }

    public static String get(String url, Map<String, String> paramMap,Map<String, String> headerMap) {
        String result = null;
        CloseableHttpResponse response = null;
        String realUrl = url;
        CloseableHttpClient httpClient = HttpClients.createDefault();
        try {
            if (paramMap != null && !paramMap.isEmpty()) {
                List<NameValuePair> params = new ArrayList<>();
                for (Map.Entry<String, String> entry : paramMap.entrySet()) {
                    params.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
                }
                String paramStr = EntityUtils.toString(new UrlEncodedFormEntity(params, "UTF-8"));
                realUrl += "?" + paramStr;
            }
            HttpGet httpGet = new HttpGet(realUrl);
            if (headerMap != null && !headerMap.isEmpty()) {
                for (Map.Entry<String, String> headerItem : headerMap.entrySet()) {
                    httpGet.setHeader(headerItem.getKey(), headerItem.getValue());
                }
            }
            response = httpClient.execute(httpGet);
            if (response != null && response.getStatusLine().getStatusCode() == 200) {
                HttpEntity entity = response.getEntity();
                if (entity != null) {
                    result = EntityUtils.toString(entity);
                }
                logger.info("url: {}, result: {}", url, result);
            }
            return result;
        } catch (Exception e) {
            logger.error("url: {}, result: {}", url, result, e);
            throw new RuntimeException(e);
        } finally {
            try {
                httpClient.close();
                if (response != null) {
                    response.close();
                }
            } catch (IOException e) {
                logger.error("", e);
                throw new RuntimeException(e);
            }
        }
    }

    public static String get(String url, Map<String, String> paramMap) {
      return get(url,paramMap,null);
    }

    public static String get(String url) {
        return get(url, null);
    }

    public static String post(String url, Map<String, String> paramMap, Map<String, String> headerMap) {
       return post(url,paramMap,headerMap,null);
    }

    public static String post(String url, Map<String, String> paramMap, Map<String, String> headerMap,String jsonStr) {
        HttpPost httpPost = null;
        CloseableHttpClient httpClient = null;
        try {
            httpPost = new HttpPost(url);
            if (paramMap != null && !paramMap.isEmpty()) {
                List<NameValuePair> formParams = new ArrayList<>();
                for (Map.Entry<String, String> entry : paramMap.entrySet()) {
                    formParams.add(new BasicNameValuePair(entry.getKey(), entry.getValue()));
                }
                httpPost.setEntity(new UrlEncodedFormEntity(formParams, "UTF-8"));
            }
            RequestConfig requestConfig = RequestConfig.custom().setSocketTimeout(50000).setConnectTimeout(50000).build();
            httpPost.setConfig(requestConfig);

            if (headerMap != null && !headerMap.isEmpty()) {
                for (Map.Entry<String, String> headerItem : headerMap.entrySet()) {
                    httpPost.setHeader(headerItem.getKey(), headerItem.getValue());
                }
            }
             if(StringUtils.isNotEmpty(jsonStr)){
                 StringEntity stringEntity=new StringEntity(jsonStr, ContentType.APPLICATION_JSON);
                 httpPost.setEntity(stringEntity);
             }
            httpClient = HttpClients.custom().disableAutomaticRetries().build();

            HttpResponse response = httpClient.execute(httpPost);
            HttpEntity entity = response.getEntity();
            if (entity != null && response.getStatusLine().getStatusCode() == 200) {
                String result = EntityUtils.toString(entity, "UTF-8");
                EntityUtils.consume(entity);
                logger.info("url: {}, result: {}", url, result);
                return result;
            }
            return null;
        } catch (Exception e) {
            logger.error("url: {}, paramMap: {}", url, paramMap, e);
            throw new RuntimeException(e);
        } finally {
            if (httpPost != null) {
                httpPost.releaseConnection();
            }
            if (httpClient != null) {
                try {
                    httpClient.close();
                } catch (IOException e) {
                    logger.error("", e);
                }
            }
        }
    }

    public static String post(String url, Map<String, String> paramMap) {
        return post(url, paramMap, null);
    }

    public static String postHeader(String url, Map<String, String> headerMap) {
        return post(url, null, headerMap);
    }
}
